@@ -32,7 +32,7 @@ extern QString DocDir;
 ImIconProvider::ImIconProvider(QWidget *pa) : QFileIconProvider(pa)
 {
 	fmts.clear();
-	QString tmp[] = {"eps", "gif", "png", "jpg", "xpm", "tif", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm"};
+	QString tmp[] = {"eps", "gif", "png", "jpg", "jpeg", "xpm", "tif", "bmp", "pbm", "pgm", "ppm", "xbm", "xpm"};
 	size_t array = sizeof(tmp) / sizeof(*tmp);
 	for (uint a = 0; a < array; ++a)
 		fmts += tmp[a];
@@ -105,30 +105,48 @@ void FDialogPreview::GenPreview(QString name)
 	updtPix();
 	int w = pixmap()->width();
 	int h = pixmap()->height();
-	QImage im = LoadPict(name);
-	if (!im.isNull())
+	QString ext = fi.extension(false).lower();
+	QStringList formats;
+	formats = QStringList::fromStrList(QImageIO::inputFormats());
+	formats.append("jpg");
+#ifdef HAVE_TIFF
+	formats.append("tif");
+	formats.append("tiff");
+#endif
+	formats.append("eps");
+	formats.append("pdf");
+	formats.append("ps");
+	QString allFormats = formats.join( " " );
+	formats.clear();
+	allFormats = allFormats.lower();
+	formats = QStringList::split( " ", allFormats );
+	if (formats.contains(ext))
 	{
-		int ix = im.width();
-		int iy = im.height();
-		QString tmp = "";
-		QString tmp2 = "";
-		if ((im.width() > w-5) || (im.height() > h-20))
+		QImage im = LoadPict(name);
+		if (!im.isNull())
 		{
-			QImage im2;
-			double sx = im.width() / static_cast<double>(w-5);
-			double sy = im.height() / static_cast<double>(h-20);
-			im2 = sy < sx ?  im.smoothScale(qRound(im.width() / sx), qRound(im.height() / sx)) :
-								im.smoothScale(qRound(im.width() / sy), qRound(im.height() / sy));
-			im = im2;
-			im2.detach();
+			int ix = im.width();
+			int iy = im.height();
+			QString tmp = "";
+			QString tmp2 = "";
+			if ((im.width() > w-5) || (im.height() > h-20))
+			{
+				QImage im2;
+				double sx = im.width() / static_cast<double>(w-5);
+				double sy = im.height() / static_cast<double>(h-20);
+				im2 = sy < sx ?  im.smoothScale(qRound(im.width() / sx), qRound(im.height() / sx)) :
+									im.smoothScale(qRound(im.width() / sy), qRound(im.height() / sy));
+				im = im2;
+				im2.detach();
+			}
+			QPainter p;
+			pixmap()->fill(white);
+			p.begin(pixmap());
+			p.drawImage(0, 0, im);
+			p.drawText(2, h-5, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp2.setNum(iy));
+			p.end();
+			repaint();
 		}
-		QPainter p;
-		pixmap()->fill(white);
-		p.begin(pixmap());
-		p.drawImage(0, 0, im);
-		p.drawText(2, h-5, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp2.setNum(iy));
-		p.end();
-		repaint();
 	}
 	else
 	{
@@ -156,7 +174,7 @@ void FDialogPreview::GenPreview(QString name)
 				Aut += au2;
 				setText( tr("Scribus Document")+"\n\n"+Tit+Aut);
 			}
-			else
+			else  if ((ext == "txt") || (ext == "html") || (ext == "xml"))
 				setText(Buffer.left(200));
 		}
 	}
@@ -237,7 +255,7 @@ CustomFDialog::CustomFDialog(QWidget *pa, QString wDir, QString cap, QString fil
 			QString tmp_txc[] = {"ISO 8859-1", "ISO 8859-2", "ISO 8859-3", "ISO 8859-4", "ISO 8859-5", "ISO 8859-6",
 								"ISO 8859-7", "ISO 8859-8", "ISO 8859-9", "ISO 8859-10", "ISO 8859-13", "ISO 8859-14",
 								"ISO 8859-15", "utf8", "KOI8-R", "KOI8-U", "CP1250", "CP1251", "CP1252", "CP1253",
-								"CP1254", "CP1255", "CP1256", "CP1257"};
+								"CP1254", "CP1255", "CP1256", "CP1257", "Apple Roman"};
 			size_t array = sizeof(tmp_txc) / sizeof(*tmp_txc);
 			for (uint a = 0; a < array; ++a)
 				TxCodeM->insertItem(tmp_txc[a]);
