@@ -32,7 +32,9 @@
 #include <cstdlib>
 #include <string>
 #include "scribus.h"
+#include "prefsfile.h"
 
+extern PrefsFile* prefsFile;
 /*!
  \fn Hyphenator::Hyphenator(QWidget* parent, ScribusDoc *dok, ScribusApp* app)
  \brief Constructor reads user configuration and sets hyphenator properties.
@@ -178,7 +180,7 @@ void Hyphenator::slotHyphenateWord(PageItem* it, QString text, int firstC)
 
 	uint maxC = it->Ptext.count() - 1;
 	QString found = text;
-	if (static_cast<int>(found.length()) > MinWordLen)
+	if (static_cast<int>(found.length()) > MinWordLen-1)
 	{
   		te = codec->fromUnicode( found );
 		word = te.data();
@@ -267,8 +269,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 	QString found2 = "";
 	uint maxC = nb1->Ptext.count() - 1;
 	qApp->setOverrideCursor(QCursor(waitCursor), true);
-	while ((firstC+Ccount < static_cast<int>(text.length())) && (firstC != -1) && 
-			(lastC < static_cast<int>(text.length())))
+	while ((firstC+Ccount < static_cast<int>(text.length())) && (firstC != -1) && (lastC < static_cast<int>(text.length())))
 	{
 		firstC = text.find(QRegExp("\\w"), firstC+Ccount);
 		if (firstC < 0)
@@ -277,7 +278,7 @@ void Hyphenator::slotHyphenate(PageItem* it)
 		if (lastC < 0)
 			lastC = static_cast<int>(text.length());
 		Ccount = lastC - firstC;
-		if (Ccount > MinWordLen)
+		if (Ccount > MinWordLen-1)
 		{
 			found = text.mid(firstC, Ccount).lower();
 			found2 = text.mid(firstC, Ccount);
@@ -315,7 +316,12 @@ void Hyphenator::slotHyphenate(PageItem* it)
 						}
 						outs += found2.right(1);
 						qApp->setOverrideCursor(QCursor(ArrowCursor), true);
+						PrefsContext* prefs = prefsFile->getContext("hyhpen_options");
+						int xpos = prefs->getInt("Xposition", -9999);
+						int ypos = prefs->getInt("Yposition", -9999);
 						HyAsk *dia = new HyAsk((QWidget*)parent(), outs);
+						if ((xpos != -9999) && (ypos != -9999))
+							dia->move(xpos, ypos);
 						qApp->processEvents();
 						if (dia->exec())
 						{
@@ -333,9 +339,13 @@ void Hyphenator::slotHyphenate(PageItem* it)
 						else
 						{
 							free(buffer);
+							prefs->set("Xposition", dia->xpos);
+							prefs->set("Yposition", dia->ypos);
 							delete dia;
 							break;
 						}
+						prefs->set("Xposition", dia->xpos);
+						prefs->set("Yposition", dia->ypos);
 						delete dia;
   						qApp->setOverrideCursor(QCursor(waitCursor), true);
 					}
