@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "about.h"
 #include "about.moc"
 #include <qpixmap.h>
@@ -58,7 +66,7 @@ About::About( QWidget* parent )
 	tabLayout1->addWidget( PixmapLabel1 );
 	BuildID = new QLabel( tab, "BB" );
 	BuildID->setAlignment(Qt::AlignCenter);
-	QString bu = tr("%1. %2 %3 ").arg("08").arg("January").arg("2005");
+	QString bu = tr("%1 %2 %3 ").arg("05").arg("July").arg("2005");
 #ifdef HAVE_CMS
 	bu += "C";
 #else
@@ -87,13 +95,13 @@ About::About( QWidget* parent )
 	TextView1 = new QTextView( tab_2, "TextView1" );
 	TextView1->setText(QString::fromUtf8("<table><tr><td><b>" + tr("Development Team:").utf8() + "</b></td><td> </td></tr>" +
 										"<tr><td>Franz Schmid</td><td>Franz.Schmid@altmuehlnet.de</td></tr>" +
-										"<tr><td>Peter Linnell</td><td>scribusdocs@atlantictechsolutions.com</td></tr>" + 
+										"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" + 
 										"<tr><td>Paul F. Johnson</td><td>paul@all-the-johnsons.co.uk</td></tr>" +
 										"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 										"<tr><td>Petr Vaněk</td><td>petr@yarpen.cz</td></tr>" +
-										"<tr><td>Riku Leino</td><td>riku.leino@gmail.com</td></tr>" +
+										"<tr><td>Riku Leino</td><td>riku.leino@gmail.com</td></tr>"+
+										"<tr><td>Craig  Ringer</td><td>craig@postnewspapers.com.au</td></tr>" +
 										"<tr><td> </td><td> </td></tr>" +
-
 										"<tr><td><b>" + tr("Contributions from:").utf8()  + "</b></td><td></td></tr>" +
 										"<tr><td>Niyam Bhushan</td><td></td></tr>" +
 										"<tr><td>Martin Costabel</td><td></td></tr>" +
@@ -105,7 +113,6 @@ About::About( QWidget* parent )
 										"<tr><td>Marti Maria</td><td></td></tr>" +
 										"<tr><td>Alexandre Prokoudine</td><td>techwriter@land.ru</td></tr>"
 										"<tr><td>Alessandro Rimoldi</td><td>http://ideale.ch/contact</td></tr>" +
-										"<tr><td>Craig Ringer</td><td></td></tr>" +
 										"<tr><td>Alastair Robinson</td><td>blackfive@fakenhamweb.co.uk</td></tr>" +
 										"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" +
 										"<tr><td>Jean-Jacques Sarton</td><td>jj.sarton@t-online.de</td></tr>" +
@@ -119,10 +126,11 @@ About::About( QWidget* parent )
  #endif
 #endif
 										"<tr><td><b>" + tr("Official Documentation:").utf8()  + "</b></td><td></td></tr>" +
-										"<tr><td>Peter Linnell</td><td>scribusdocs@atlantictechsolutions.com</td></tr>" + 
+										"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" + 
 										"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 										"<tr><td>Frédéric Dubuy</td><td>effediwhy@gmail.com</td></tr>" +
 										"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" + 
+										"<tr><td>Louis Desjardins</td><td>louisdesjardins@videotron.ca</td></tr>" + 
 										"<tr><td> </td><td> </td></tr>" +
 
 										"<tr><td><b>" + tr("Other Documentation:").utf8()  + "</b></td><td></td></tr>" +
@@ -138,7 +146,7 @@ About::About( QWidget* parent )
 	tabLayout_2->setMargin( 10 );
 	TextView2 = new QTextView( tab_3, "TextView1_2" );
 	TextView2->setText(QString::fromUtf8( "<table><tr><td><b><i>" + tr("Official Translations and Translators:").utf8() + "</i></b></td><td></td></tr>" +
-	                                      "<tr><td><b>" + QString("Afrikaans:").utf8()  + "</b></td><td></td></tr>" +
+	                                      "<tr><td><b>" + tr("Afrikaans:").utf8()  + "</b></td><td></td></tr>" +
 	                                      "<tr><td>Kobus Wolvaardt</td><td>kobuswolf@diewereld.co.za</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
 									      "<tr><td><b>" + tr("Catalan:").utf8()  + "</b></td><td> </td></tr>" +
@@ -183,6 +191,10 @@ About::About( QWidget* parent )
 	                                      "<tr><td><b>" + tr("Polish:").utf8()  + "</b></td><td> </td></tr>" +
 	                                      "<tr><td>Maciej Hański</td><td>m.hanski@gmx.at</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
+	                                      "<tr><td><b>" + tr("Portuguese (Brazilian):").utf8()  + "</b></td><td> </td></tr>" +
+	                                      "<tr><td>Ludi Maciel</td><td>iludi@uol.com.br</td></tr>" +
+                                          "<tr><td>Frederico Gon&#231;alves</td><td></td></tr>" +
+	                                      "<tr><td> </td><td> </td></tr>" +	
 	                                      "<tr><td><b>" + tr("Russian:").utf8()  + "</b></td><td></td></tr>" +
 	                                      "<tr><td>Alexandre Prokoudine</td><td>techwriter@land.ru</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
