@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "prefs.h"
 #include "prefs.moc"
 #include "keymanager.h"
@@ -211,10 +219,14 @@ Preferences::Preferences( QWidget* parent, preV *Vor)
 	ProPfad = new QLineEdit( GroupBox200, "Datei1" );
 	ProPfad->setMinimumSize( QSize( 268, 22 ) );
 	ProPfad->setText(Vor->ProfileDir);
+	if (ap->HaveDoc)
+		ProPfad->setEnabled(false);
 	PfadText2 = new QLabel( ProPfad, tr("&ICC Profiles:"), GroupBox200, "Pfadtext1" );
 	FileC2 = new QToolButton( GroupBox200, "FileC1" );
 	FileC2->setMinimumSize( QSize( 88, 24 ) );
 	FileC2->setText( tr( "C&hange..." ) );
+	if (ap->HaveDoc)
+		FileC2->setEnabled(false);
 	GroupBox200Layout->addWidget( PfadText2, 1, 0 );
 	GroupBox200Layout->addWidget( ProPfad, 1, 1 );
 	GroupBox200Layout->addWidget( FileC2, 1, 2 );
@@ -1521,7 +1533,7 @@ Preferences::Preferences( QWidget* parent, preV *Vor)
 	QToolTip::add( SpinBox3_2, tr( "Radius of the area where Scribus will allow you to grab an objects handles" ) );
 	QToolTip::add( Recen, tr( "Number of recently edited documents to show in the File menu" ) );
 	QToolTip::add( Docs, tr( "Default documents directory" ) );
-	QToolTip::add( ProPfad, tr( "Default ICC profiles directory" ) );
+	QToolTip::add( ProPfad, tr( "Default ICC profiles directory. This cannot\nbe changed with documents open." ) );
 	QToolTip::add( ScriptPfad, tr( "Default Scripter scripts directory" ) );
 	QToolTip::add( TemplateDir, tr( "Additional Directory for Document Templates" ) );
 
@@ -1546,8 +1558,8 @@ Preferences::Preferences( QWidget* parent, preV *Vor)
 	QToolTip::add( GuideColor, tr( "Color of the guide lines you insert" ) );
 	QToolTip::add( RadioButton6, tr( "Place the grid behind your page objects" ) );
 	QToolTip::add( RadioButton7, tr( "Place the grid in front of your page objects" ) );
-	QToolTip::add( RadioButton8, tr("Turns on the basegrid"));
-	QToolTip::add( RadioButton9, tr("Turns off the basegrid"));
+	QToolTip::add( RadioButton8, tr("Turns on the base grid"));
+	QToolTip::add( RadioButton9, tr("Turns off the base grid"));
 
 	QToolTip::add( VHochW, tr( "Displacement above the baseline of the font on a line" ) );
 	QToolTip::add( VHochWSc, tr( "Relative size of the superscript compared to the normal font" ) );
@@ -1615,10 +1627,13 @@ Preferences::Preferences( QWidget* parent, preV *Vor)
 	QToolTip::add( UsePDFTrans, tr( "Enable transparency features within PDF 1.4 export" ) );
 	QToolTip::add( CaliSlider, tr( "Set the default zoom level" ) );
 
-	QToolTip::add( GSName, tr( "Filesystem location for the Ghostscript interpreter" ) );
+	QToolTip::add( GSName, tr( "File system location for the Ghostscript interpreter" ) );
 	QToolTip::add( GSantiText, tr( "Antialias text for EPS and PDF onscreen rendering" ) );
 	QToolTip::add( GSantiGraph, tr( "Antialias graphics for EPS and PDF onscreen rendering" ) );
-	QToolTip::add( GimpName, tr( "Filesystem location for graphics editor" ) );
+	QToolTip::add( GimpName, tr( "File system location for graphics editor. If you use gimp\n"
+						"and your distro includes it, we recommend 'gimp-remote',\n"
+						"as it allows you to edit the image in an already running\n"
+						"instance of gimp." ) );
 
 	QToolTip::add( ClipMarg, tr( "Do not show objects outside the margins on the printed page or exported file" ) );
 	QToolTip::add( DoGCR, tr( "A way of switching off some of the gray shades which are composed\n"
