@@ -44,9 +44,12 @@ using namespace std;
 
 extern double Cwidth(ScribusDoc *doc, QString name, QString ch, int Siz, QString ch2 = " ");
 extern double RealCWidth(ScribusDoc *doc, QString name, QString ch, int Siz);
+extern double RealCHeight(ScribusDoc *currentDoc, QString name, QString ch, int Size);
+extern double RealCAscent(ScribusDoc *currentDoc, QString name, QString ch, int Size);
 extern QPointArray FlattenPath(FPointArray ina, QValueList<uint> &Segs);
 extern double xy2Deg(double x, double y);
 extern void BezierPoints(QPointArray *ar, QPoint n1, QPoint n2, QPoint n3, QPoint n4);
+extern int Layer2Level(ScribusDoc *currentDoc, int LayerNr);
 extern ScribusApp* ScApp;
 
 PageItem::PageItem(Page *pa, int art, double x, double y, double w, double h, double w2, QString fill, QString outline, ScribusDoc *doc) : QObject(pa)
@@ -148,6 +151,7 @@ PageItem::PageItem(Page *pa, int art, double x, double y, double w, double h, do
 	PoShow = false;
 	BaseOffs = 0;
 	OwnPage = pa;
+	savedOwnPage = OwnPage;
 	PicArt = true;
 	PicAvail = false;
 	isPrintable = true;
@@ -193,6 +197,7 @@ PageItem::PageItem(Page *pa, int art, double x, double y, double w, double h, do
 		break;
 	}
 	AnName += tmp.setNum(Doc->TotalItems); // +" "+QDateTime::currentDateTime().toString();
+	setName(QString("pageItem%1").arg(Doc->TotalItems).ascii());
 	AutoName = true;
 	Doc->TotalItems++;
 	AnToolTip = "";
@@ -279,10 +284,10 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 	QPoint pt1, pt2;
 	FPoint gv, ColBound;
 	QRegion cm;
-	uint a, nrc, nrc2, zae, startLin;
-	int desc, asce, absa, aSpa, chs, chsd, CurrCol;
+	uint a, nrc, nrc2, startLin;
+	int absa, aSpa, chs, chsd, CurrCol;
 	uint BuPos, LastSP, MaxText;
-	double oldCurY, LastXp, EndX, OFs, OFs2, wide, rota, wid, lineCorr, ColWidth, kernVal, RTabX;
+	double desc, asce, oldCurY, LastXp, EndX, OFs, OFs2, wide, lineCorr, ColWidth, kernVal, RTabX;
 	double sc = Doc->Scale;
 	QString chx, chx2, chx3;
 	struct Pti *hl;
@@ -602,19 +607,22 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 					Zli3.Siz = chs;
 					Zli3.Style = hl->cstyle;
 					Zli3.ZFo = hl->cfont;
-					Zli3.wide = Cwidth(Doc, hl->cfont, chx, hl->csize);
-					Zli3.kern = hl->cextra;
+					Zli3.wide = Cwidth(Doc, hl->cfont, chx, hl->csize) * (hl->cscale / 100.0);
+					if (hl->cstyle & 1024)
+						Zli3.kern = 0;
+					else
+						Zli3.kern = hl->cextra;
 					Zli3.scale = hl->cscale;
 					if (!Doc->RePos)
 					{
-						desc = qRound((*Doc->AllFonts)[Zli3.ZFo]->numDescender * (-Zli3.Siz / 10.0));
-						asce = qRound((*Doc->AllFonts)[Zli3.ZFo]->numAscent * (Zli3.Siz / 10.0));
+						desc = (*Doc->AllFonts)[Zli3.ZFo]->numDescender * (-Zli3.Siz / 10.0);
+						asce = (*Doc->AllFonts)[Zli3.ZFo]->numAscent * (Zli3.Siz / 10.0);
 						if (e.intersects(pf.xForm(QRect(qRound(Zli3.xco),qRound(Zli3.yco-asce), qRound(Zli3.wide+1), qRound(asce+desc)))))
 							DrawZeichenS(p, &Zli3);
 						if (hl->cstyle & 512)
 						{
 							Zli3.Zeich = "-";
-							Zli3.xco = Zli3.xco + Cwidth(Doc, hl->cfont, chx, hl->csize);
+							Zli3.xco = Zli3.xco + Zli3.wide;
 							if (e.intersects(pf.xForm(QRect(qRound(Zli3.xco),qRound(Zli3.yco-asce), qRound(Zli3.wide+1), qRound(asce+desc)))))
 								DrawZeichenS(p, &Zli3);
 						}
@@ -665,42 +673,81 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 					}
 				Doc->Vorlagen[0].LineSpa = LineSp;
 				QRegion cl = QRegion(pf2.xForm(Clip));
-				for (a=0; a<OwnPage->Items.count(); ++a)
+				for (a=0; a<savedOwnPage->Items.count(); ++a)
+				{
+					PageItem* ownItem = savedOwnPage->Items.at(a);
+					int LayerLevItem = Layer2Level(Doc, ownItem->LayerNr);
+					int LayerLev = Layer2Level(Doc, LayerNr);
+					if (((ownItem->ItemNr > ItemNr) && (ownItem->LayerNr == LayerNr)) || (LayerLevItem > LayerLev))
 					{
-					if (((OwnPage->Items.at(a)->ItemNr > ItemNr) && (OwnPage->Items.at(a)->LayerNr == LayerNr))
-   							|| (Doc->Layers[OwnPage->Items.at(a)->LayerNr].Level > Doc->Layers[LayerNr].Level))
+						if (ownItem->Textflow)
 						{
-						if (OwnPage->Items.at(a)->Textflow)
-							{
 							pp.begin(Parent);
-							pp.translate(OwnPage->Items.at(a)->Xpos, OwnPage->Items.at(a)->Ypos);
-							pp.rotate(OwnPage->Items.at(a)->Rot);
-							if (OwnPage->Items.at(a)->Textflow2)
-								{
+							pp.translate(ownItem->Xpos, ownItem->Ypos);
+							pp.rotate(ownItem->Rot);
+							if (ownItem->Textflow2)
+							{
 								QPointArray tcli;
 								tcli.resize(4);
 								tcli.setPoint(0, QPoint(0,0));
-								tcli.setPoint(1, QPoint(qRound(OwnPage->Items.at(a)->Width), 0));
-								tcli.setPoint(2, QPoint(qRound(OwnPage->Items.at(a)->Width), qRound(OwnPage->Items.at(a)->Height)));
-								tcli.setPoint(3, QPoint(0, qRound(OwnPage->Items.at(a)->Height)));
+								tcli.setPoint(1, QPoint(qRound(ownItem->Width), 0));
+								tcli.setPoint(2, QPoint(qRound(ownItem->Width), qRound(ownItem->Height)));
+								tcli.setPoint(3, QPoint(0, qRound(ownItem->Height)));
 								cm = QRegion(pp.xForm(tcli));
-								}
+							}
 							else
 							{
-								if ((OwnPage->Items.at(a)->UseContour) && (OwnPage->Items.at(a)->ContourLine.size() != 0))
+								if ((ownItem->UseContour) && (ownItem->ContourLine.size() != 0))
 								{
 									QValueList<uint> Segs;
-									QPointArray Clip2 = FlattenPath(OwnPage->Items.at(a)->ContourLine, Segs);
+									QPointArray Clip2 = FlattenPath(ownItem->ContourLine, Segs);
 									cm = QRegion(pp.xForm(Clip2));
 								}
 								else
-									cm = QRegion(pp.xForm(OwnPage->Items.at(a)->Clip));
+									cm = QRegion(pp.xForm(ownItem->Clip));
 							}
 							pp.end();
 							cl = cl.subtract(cm);
-							}
 						}
 					}
+				}
+				if (savedOwnPage->PageNam != "")
+				{
+					Page* par = (Page*)Parent;
+					for (a=0; a<par->Items.count(); ++a)
+					{
+						PageItem* parItem = par->Items.at(a);
+						if (parItem->Textflow)
+						{
+							pp.begin(Parent);
+							pp.translate(parItem->Xpos, parItem->Ypos);
+							pp.rotate(parItem->Rot);
+							if (parItem->Textflow2)
+							{
+								QPointArray tcli;
+								tcli.resize(4);
+								tcli.setPoint(0, QPoint(0,0));
+								tcli.setPoint(1, QPoint(qRound(parItem->Width), 0));
+								tcli.setPoint(2, QPoint(qRound(parItem->Width), qRound(parItem->Height)));
+								tcli.setPoint(3, QPoint(0, qRound(parItem->Height)));
+								cm = QRegion(pp.xForm(tcli));
+							}
+							else
+							{
+								if ((parItem->UseContour) && (parItem->ContourLine.size() != 0))
+								{
+									QValueList<uint> Segs;
+									QPointArray Clip2 = FlattenPath(parItem->ContourLine, Segs);
+									cm = QRegion(pp.xForm(Clip2));
+								}
+								else
+									cm = QRegion(pp.xForm(parItem->Clip));
+							}
+							pp.end();
+							cl = cl.subtract(cm);
+						}
+					}
+				}
 				if (flippedH % 2 != 0)
 				{
 					p->translate(Width * sc, 0);
@@ -771,8 +818,6 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 									{
 									if (nb->Ptext.at(nb->Ptext.count()-1)->ch == QChar(13))
 										{
-										CurX += Doc->Vorlagen[absa].First;
-										CurX += Doc->Vorlagen[absa].Indent;
 										CurY += Doc->Vorlagen[absa].Avor;
 										if (chx != QChar(13))
 											DropCmode = Doc->Vorlagen[absa].Drop;
@@ -783,10 +828,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 										break;
 										}
 									else
-										{
-										CurX += Doc->Vorlagen[absa].Indent;
 										break;
-										}
 									}
 								nb = nb->BackBox;
 								}
@@ -797,8 +839,6 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 								DropCmode = Doc->Vorlagen[absa].Drop;
 							else
 								DropCmode = false;
-							CurX += Doc->Vorlagen[absa].First;
-							CurX += Doc->Vorlagen[absa].Indent;
 							CurY += Doc->Vorlagen[absa].Avor;
 							if (DropCmode)
 								DropLines = Doc->Vorlagen[absa].DropLin;
@@ -815,8 +855,6 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						{
 						if ((a > 0) && (Ptext.at(a-1)->ch == QChar(13)))
 							{
-							CurX += Doc->Vorlagen[absa].First;
-							CurX += Doc->Vorlagen[absa].Indent;
 							CurY += Doc->Vorlagen[absa].Avor;
 							if (chx != QChar(13))
 								DropCmode = Doc->Vorlagen[absa].Drop;
@@ -836,13 +874,13 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						{
 						if (Doc->Vorlagen[hl->cab].BaseAdj)
 						{
-							chsd = qRound(10 * ((Doc->BaseGrid * DropLines) / ((*Doc->AllFonts)[hl->cfont]->numAscent+(*Doc->AllFonts)[hl->cfont]->numDescender)));
-							chs = qRound(10 * ((Doc->BaseGrid * DropLines) / (*Doc->AllFonts)[hl->cfont]->numAscent));
+							chsd = qRound(10 * ((Doc->BaseGrid * DropLines) / (RealCHeight(Doc, hl->cfont, chx, 10))));
+							chs = qRound(10 * ((Doc->BaseGrid * DropLines) / RealCAscent(Doc, hl->cfont, chx, 10)));
 						}
 						else
 						{
-							chsd = qRound(10 * ((Doc->Vorlagen[absa].LineSpa * DropLines) / ((*Doc->AllFonts)[hl->cfont]->numAscent+(*Doc->AllFonts)[hl->cfont]->numDescender)));
-							chs = qRound(10 * ((Doc->Vorlagen[absa].LineSpa * DropLines) / (*Doc->AllFonts)[hl->cfont]->numAscent));
+							chsd = qRound(10 * ((Doc->Vorlagen[absa].LineSpa * DropLines) / (RealCHeight(Doc, hl->cfont, chx, 10))));
+							chs = qRound(10 * ((Doc->Vorlagen[absa].LineSpa * DropLines) / RealCAscent(Doc, hl->cfont, chx, 10)));
 						}
 						hl->csize = chsd;
 						}
@@ -868,16 +906,56 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						wide = RealCWidth(Doc, hl->cfont, chx2, chsd);
 						desc2 = 0;
 						desc = 0;
-						asce = qRound((*Doc->AllFonts)[hl->cfont]->numAscent * (chs / 10.0));
+						asce = RealCHeight(Doc, hl->cfont, chx2, chsd);
 					}
 					else
 					{
-						desc2 = -(*Doc->AllFonts)[hl->cfont]->numDescender * (chs / 10.0);
-						desc = qRound(-(*Doc->AllFonts)[hl->cfont]->numDescender * (chs / 10.0));
-						asce = qRound((*Doc->AllFonts)[hl->cfont]->numAscent * (chs / 10.0));
+						desc2 = -(*Doc->AllFonts)[hl->cfont]->numDescender * (hl->csize / 10.0);
+						desc = -(*Doc->AllFonts)[hl->cfont]->numDescender * (hl->csize / 10.0);
+						asce = (*Doc->AllFonts)[hl->cfont]->numAscent * (hl->csize / 10.0);
 					}
 					wide = wide * (hl->cscale / 100.0);
 					fBorder = false;
+					if (CurY+BExtra+lineCorr > Height)
+					{
+						StartOfCol = true;
+						CurrCol++;
+						if (CurrCol < Cols)
+						{
+							ColWidth = (Width - (ColGap * (Cols - 1)) - Extra - RExtra - 2*lineCorr) / Cols;
+							ColBound = FPoint((ColWidth + ColGap) * CurrCol + Extra+lineCorr, ColWidth * (CurrCol+1) + ColGap * CurrCol + Extra+lineCorr);
+							CurX = ColBound.x();
+							ColBound = FPoint(ColBound.x(), ColBound.y()+RExtra+lineCorr);
+							CurY = asce+TExtra+lineCorr+1;
+							if ((a > 0) && (Ptext.at(a-1)->ch == QChar(13)))
+							{
+								if (chx != QChar(13))
+									DropCmode = Doc->Vorlagen[hl->cab].Drop;
+								else
+									DropCmode = false;
+								if (DropCmode)
+								{
+									if (Doc->Vorlagen[hl->cab].BaseAdj)
+										desc2 = -(*Doc->AllFonts)[hl->cfont]->numDescender * Doc->BaseGrid * Doc->Vorlagen[hl->cab].DropLin;
+									else
+										desc2 = -(*Doc->AllFonts)[hl->cfont]->numDescender * Doc->Vorlagen[hl->cab].LineSpa * Doc->Vorlagen[hl->cab].DropLin;
+								}
+								if (DropCmode)
+									DropLines = Doc->Vorlagen[hl->cab].DropLin;
+							}
+							if (Doc->Vorlagen[hl->cab].BaseAdj)
+							{
+								int ol1 = qRound((Ypos + CurY - Doc->BaseOffs) * 10000.0);
+								int ol2 = static_cast<int>(ol1 / Doc->BaseGrid);
+								CurY = ceil(  ol2 / 10000.0 ) * Doc->BaseGrid + Doc->BaseOffs - Ypos;
+							}
+						}
+						else
+						{
+							nrc = a;
+							goto NoRoom;
+						}
+					}
 					if (LiList.isEmpty())
 						{
 						startLin = a;
@@ -887,12 +965,8 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						if (StartOfCol)
 						{
 							CurY = asce+TExtra+lineCorr+1;
-							if ((a > 0) && (Ptext.at(a-1)->ch == QChar(13)))
-							{
+							if (((a > 0) && (Ptext.at(a-1)->ch == QChar(13))) || ((a == 0) && (BackBox == 0)))
 								CurY += Doc->Vorlagen[hl->cab].Avor;
-								CurX += Doc->Vorlagen[hl->cab].First;
-								CurX += Doc->Vorlagen[hl->cab].Indent;
-							}
 						}
 						if (Doc->Vorlagen[hl->cab].BaseAdj)
 						{
@@ -913,14 +987,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 								fBorder = false;
 								if (StartOfCol)
 								{
-									if (((a > 0) && (Ptext.at(a-1)->ch == QChar(13))) || (a == 0))
-									{
-										CurX = ColBound.x();
-										CurX += Doc->Vorlagen[hl->cab].First;
-										CurX += Doc->Vorlagen[hl->cab].Indent;
-									}
-									else
-										CurX = ColBound.x();
+									CurX = ColBound.x();
 									CurY++;
 								}
 								else
@@ -952,8 +1019,6 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 												DropCmode = Doc->Vorlagen[hl->cab].Drop;
 											else
 												DropCmode = false;
-											CurX += Doc->Vorlagen[hl->cab].First;
-											CurX += Doc->Vorlagen[hl->cab].Indent;
 											if (DropCmode)
 											{
 												if (Doc->Vorlagen[hl->cab].BaseAdj)
@@ -964,8 +1029,6 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 											if (DropCmode)
 												DropLines = Doc->Vorlagen[hl->cab].DropLin;
 											}
-										else
-											CurX += Doc->Vorlagen[hl->cab].Indent;
 										if (Doc->Vorlagen[hl->cab].BaseAdj)
 										{
 											int ol1 = qRound((Ypos + CurY - Doc->BaseOffs) * 10000.0);
@@ -985,6 +1048,28 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 							}
 						if ((fBorder) && (!AbsHasDrop))
 							CurX += Extra;
+						if (a > 0)
+						{
+							if (Ptext.at(a-1)->ch == QChar(13))
+								CurX += Doc->Vorlagen[hl->cab].First;
+						}
+						else
+						{
+							if (BackBox == 0)
+								CurX += Doc->Vorlagen[hl->cab].First;
+							else
+							{
+								if (BackBox->Ptext.count() != 0)
+								{
+									if (BackBox->Ptext.at(BackBox->Ptext.count()-1)->ch == QChar(13))
+										CurX += Doc->Vorlagen[hl->cab].First;
+								}
+								else
+									CurX += Doc->Vorlagen[hl->cab].First;
+							}
+						}
+						if (!AbsHasDrop)
+							CurX += Doc->Vorlagen[hl->cab].Indent;
 						fBorder = false;
 						}
 					StartOfCol = false;
@@ -1013,7 +1098,12 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 							if (tTabValues.isEmpty())
 								{
 								if ((CurX - ColBound.x()) != 0)
-									CurX = ColBound.x() + ceil((CurX-ColBound.x()) / 36.0) * 36.0;
+								{
+									if (CurX == ColBound.x() + ceil((CurX-ColBound.x()) / 36.0) * 36.0)
+										CurX += 36.0;
+									else
+										CurX = ColBound.x() + ceil((CurX-ColBound.x()) / 36.0) * 36.0;
+								}
 								else
 									CurX = ColBound.x() + 36.0;
 								TabCode = 0;
@@ -1046,10 +1136,18 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 							}
 						}
 					hl->yp = CurY + oldCurY;
+					if (DropCmode)
+						hl->yp -= RealCHeight(Doc, hl->cfont, chx2, chsd) - RealCAscent(Doc, hl->cfont, chx2, chsd);
 					if (LiList.count() == 0)
+					{
+						Ptext.at(a)->cstyle |= 1024;
 						kernVal = 0;
+					}
 					else
+					{
 						kernVal = hl->cextra;
+						Ptext.at(a)->cstyle &= 1023;
+					}
 					if (!RTab)
 						{
 						hl->xp = CurX+kernVal;
@@ -1059,12 +1157,17 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						hl->xp = CurX;
 					if ((TabCode == 4) && (RTab))
 						CurX += (wide+kernVal) / 2;
-					if ((hl->cstyle & 128) || (hl->ch == "-"))
+					if (((hl->cstyle & 128) || (hl->ch == "-")) && ((HyphenCount < Doc->HyCount) || (Doc->HyCount == 0)))
 					{
-						if ((HyphenCount < Doc->HyCount) || (Doc->HyCount == 0))
+						if (hl->cstyle & 128)
 						{
-							pt1 = QPoint(qRound(ceil(CurX+RExtra+Cwidth(Doc, hl->cfont, "-", hl->csize))), qRound(CurY+desc));
-							pt2 = QPoint(qRound(ceil(CurX+RExtra+Cwidth(Doc, hl->cfont, "-", hl->csize))), qRound(ceil(CurY-asce)));
+							pt1 = QPoint(qRound(ceil(CurX+RExtra+Cwidth(Doc, hl->cfont, "-", hl->csize) * (hl->cscale / 100.0))), qRound(CurY+desc));
+							pt2 = QPoint(qRound(ceil(CurX+RExtra+Cwidth(Doc, hl->cfont, "-", hl->csize) * (hl->cscale / 100.0))), qRound(ceil(CurY-asce)));
+						}
+						else
+						{
+							pt1 = QPoint(qRound(ceil(CurX+RExtra)), qRound(CurY+desc));
+							pt2 = QPoint(qRound(ceil(CurX+RExtra)), qRound(ceil(CurY-asce)));
 						}
 					}
 					else
@@ -1117,7 +1220,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 							if (hl->ch == "-")
 								LastXp = CurX;
 							else
-								LastXp = CurX + Cwidth(Doc, hl->cfont, "-", hl->csize);
+								LastXp = CurX + Cwidth(Doc, hl->cfont, "-", hl->csize) * (hl->cscale / 100.0);
 							LastSP = BuPos;
 						}
 					}
@@ -1189,7 +1292,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 									Zli->Farb2 = Ptext.at(a)->cstroke;
 									Zli->shade = Ptext.at(a)->cshade;
 									Zli->shade2 = Ptext.at(a)->cshade2;
-									Zli->xco = LastXp - Cwidth(Doc, Ptext.at(a)->cfont, "-", Ptext.at(a)->csize);
+									Zli->xco = LastXp - Cwidth(Doc, Ptext.at(a)->cfont, "-", Ptext.at(a)->csize) * (hl->cscale / 100.0);
 									Zli->yco = Ptext.at(a)->yp;
 									Zli->Sele = Ptext.at(a)->cselect;
 									Zli->Siz = Ptext.at(a)->csize;
@@ -1253,6 +1356,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 											LiList.at(xof)->xco += OFs;
 											}
 										}
+										CurX = EndX;
 									}
 								}
 							else
@@ -1308,6 +1412,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 										LiList.at(xof)->xco += OFs;
 										}
 									}
+									CurX = EndX;
 								}
 							}
 						uint BuPos3 = BuPos;
@@ -1339,7 +1444,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 										}
 										if (AbsHasDrop)
 											{
-											if (CurY > maxDY)
+											if ((CurY > maxDY) && (CurY - asce > maxDY))
 												{
 												AbsHasDrop = false;
 												CurX = ColBound.x();
@@ -1349,13 +1454,12 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 											}
 										else
 											CurX = ColBound.x();
-										if (hl->ch != QChar(13))
-											CurX += Doc->Vorlagen[hl->cab].Indent;
-										else
+										if (hl->ch == QChar(13))
 											{
 											CurY += Doc->Vorlagen[hl->cab].Anach;
 											if (BuPos3 > 0)
 												BuPos3 -= 1;
+											HyphenCount = 0;
 											}
 										break;
 										}
@@ -1363,7 +1467,15 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 									pt2 = QPoint(qRound(CurX+RExtra), static_cast<int>(ceil(CurY-asce)));
 									}
 								if (fromOut)
+									{
+									if ((CurY+desc+BExtra+lineCorr > Height) && (CurrCol+1 == Cols))
+									{
+										goNoRoom = true;
+										break;
+									}
 									CurX--;
+									CurX = QMAX(CurX, 0);
+									}
 								}
 							else
 								{
@@ -1376,7 +1488,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 								CurY += Doc->Vorlagen[hl->cab].LineSpa;
 								if (AbsHasDrop)
 									{
-									if (CurY > maxDY)
+									if ((CurY > maxDY) && (CurY - asce > maxDY))
 										{
 										AbsHasDrop = false;
 										CurX = ColBound.x();
@@ -1386,13 +1498,12 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 									}
 								else
 									CurX = ColBound.x();
-								if (hl->ch != QChar(13))
-									CurX += Doc->Vorlagen[hl->cab].Indent;
-								else
+								if (hl->ch == QChar(13))
 									{
 									CurY += Doc->Vorlagen[hl->cab].Anach;
 									if (BuPos3 > 0)
 										BuPos3 -= 1;
+									HyphenCount = 0;
 									}
 								}
 							}
@@ -1412,8 +1523,8 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 								SetFarbe(&tmp, Zli2->Farb, Zli2->shade);
 								p->setBrush(tmp);
 							}
-							desc = static_cast<int>((*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0));
-							asce = static_cast<int>((*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0));
+							desc = (*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0);
+							asce = (*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0);
 							if ((((Zli2->Sele) && (Select)) || (((NextBox != 0) || (BackBox != 0)) && (Zli2->Sele))) && (Doc->AppMode == 7))
 							{
 								wide = Zli2->wide;
@@ -1427,7 +1538,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 									wide = Zli2->xco - xcoZli + Zli2->wide;
 								}
 								if (!Doc->RePos)
-									p->drawRect(xcoZli, Zli2->yco-asce, wide+1, asce+desc);
+									p->drawRect(xcoZli, qRound(Zli2->yco-asce), wide+1, qRound(asce+desc));
 								p->setBrush(white);
 							}
 							if (Zli2->Farb2 != "None")
@@ -1510,13 +1621,13 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 						SetFarbe(&tmp, Zli2->Farb, Zli2->shade);
 						p->setBrush(tmp);
 					}
-					desc = qRound((*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0));
-					asce = qRound((*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0));
+					desc = (*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0);
+					asce = (*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0);
 					if ((((Zli2->Sele) && (Select)) || (((NextBox != 0) || (BackBox != 0)) && (Zli2->Sele))) && (Doc->AppMode == 7))
 					{
 						wide = Zli2->wide;
-						desc = qRound((*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0));
-						asce = qRound((*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0));
+						desc = (*Doc->AllFonts)[Zli2->ZFo]->numDescender * (-Zli2->Siz / 10.0);
+						asce = (*Doc->AllFonts)[Zli2->ZFo]->numAscent * (Zli2->Siz / 10.0);
 						p->setFillMode(1);
 						p->setBrush(darkBlue);
 						p->setLineWidth(0);
@@ -1527,7 +1638,7 @@ void PageItem::DrawObj(ScPainter *p, QRect e)
 							wide = Zli2->xco - xcoZli + Zli2->wide;
 						}
 						if (!Doc->RePos)
-							p->drawRect(xcoZli, Zli2->yco-asce, wide+1, asce+desc);
+							p->drawRect(xcoZli, qRound(Zli2->yco-asce), wide+1, qRound(asce+desc));
 						p->setBrush(white);
 					}
 					if (Zli2->Farb2 != "None")
@@ -1613,26 +1724,27 @@ NoRoom: pf2.end();
 				p->restore();
 				break;
 		case 8:
+			{
 			if (!PoShow)
 				doStroke = false;
-			cl = FlattenPath(PoLine, Segments);
+			double dx;
+			double sp = 0;
+			double oldSp = 0;
+			double oCurX = 0;
+			FPoint point = FPoint(0, 0);
+			FPoint normal = FPoint(0, 0);
+			FPoint tangent = FPoint(0, 0);
+			FPoint extPoint = FPoint(0, 0);
+			bool ext = false;
+			bool first = true;
+			double fsx = 0;
+			uint seg = 0;
+			double segLen = 0;
+			double distCurX;
 			CurX = Extra;
 			if (Ptext.count() != 0)
 				CurX += Ptext.at(0)->cextra;
-			zae = 0;
-			wid = sqrt(pow(cl.point(zae+1).x()-cl.point(zae).x(),2.0)+pow(cl.point(zae+1).y()-cl.point(zae).y(),2.0));
-			while (wid < 1)
-			{
-				zae++;
-				if (zae > cl.size()-2)
-				{
-					MaxChars = Ptext.count();
-					break;
-				}
-				wid = sqrt(pow(cl.point(zae+1).x()-cl.point(zae).x(),2.0) + 
-							pow(cl.point(zae+1).y()-cl.point(zae).y(),2.0));
-			}
-			rota = xy2Deg(cl.point(zae+1).x()-cl.point(zae).x(),cl.point(zae+1).y()-cl.point(zae).y());
+			segLen = PoLine.lenPathSeg(seg);
 			for (a = 0; a < Ptext.count(); ++a)
 			{
 				CurY = 0;
@@ -1657,55 +1769,68 @@ NoRoom: pf2.end();
 				else
 					wide = Cwidth(Doc, hl->cfont, chx2, chs);
 				wide = wide * (hl->cscale / 100.0);
-				if ((CurX+(wide+hl->cextra)/2) >= wid)
+				dx = wide / 2.0;
+				CurX += dx;
+				ext = false;
+				while ( (seg < PoLine.count()-4) && (CurX > fsx + segLen))
 				{
-					if (zae < cl.size()-1)
+					fsx += segLen;
+					seg += 4;
+					segLen = PoLine.lenPathSeg(seg);
+					ext = true;
+				}
+				if ( (seg == PoLine.count()-4) && (CurX > fsx + segLen))
+					break;
+				QString db;
+				if (ext)
+				{
+					sp = 0;
+					distCurX = PoLine.lenPathDist(seg, 0, sp);
+					while (distCurX <= ((CurX - oCurX) - (fsx - oCurX)))
 					{
-						CurX = CurX - wid;
-						wid = 0;
-						EndX = CurX;
-						do
+						sp += 0.001;
+						distCurX = PoLine.lenPathDist(seg, 0, sp);
+					}
+					PoLine.pointTangentNormalAt(seg, sp, &point, &tangent, &normal );
+					CurX = (CurX - (CurX - fsx)) + distCurX;
+					oldSp = sp;
+					ext = false;
+				}
+				else
+				{
+					if( seg < PoLine.count() )
+					{
+						distCurX = PoLine.lenPathDist(seg, oldSp, sp);
+						while (distCurX <= (CurX - oCurX))
 						{
-							do
+							sp += 0.001;
+							if (sp >= 1.0)
 							{
-								zae++;
-								if (zae > cl.size()-2)
-								{
-									MaxChars = a+1;
-									break;
-								}
-								wid = sqrt(pow(cl.point(zae+1).x()-cl.point(zae).x(),2.0)+
-											pow(cl.point(zae+1).y()-cl.point(zae).y(),2.0));
-								rota = xy2Deg(cl.point(zae+1).x()-cl.point(zae).x(),
-												cl.point(zae+1).y()-cl.point(zae).y());
-							}
-							while (wid == 0);
-							EndX -= wid;
-							if (zae > cl.size()-2)
-							{
-								MaxChars = a+1;
+								sp = 0.9999;
 								break;
 							}
+							distCurX = PoLine.lenPathDist(seg, oldSp, sp);
 						}
-						while (wid < EndX);
-						CurX = EndX + wid;
+						PoLine.pointTangentNormalAt(seg, sp, &point, &tangent, &normal );
+						CurX = oCurX + distCurX;
+						oldSp = sp;
 					}
 					else
-					{
-						MaxChars = a+1;
 						break;
-					}
 				}
-				if (zae > cl.size()-2)
-					break;
+				hl->xp = point.x();
+				hl->yp = point.y();
+				hl->PtransX = tangent.x();
+				hl->PtransY = tangent.y();
+				hl->PRot = dx;
+
+				QWMatrix trafo = QWMatrix( 1, 0, 0, -1, -dx*sc, 0 );
+				trafo *= QWMatrix( tangent.x(), tangent.y(), tangent.y(), -tangent.x(), point.x()*sc, point.y()*sc );
+				QWMatrix sca = p->worldMatrix();
+				trafo *= sca;
 				p->save();
-				p->translate(cl.point(zae).x()*sc, cl.point(zae).y()*sc);
-				p->rotate(rota);
-				hl->xp = CurX+hl->cextra;
-				hl->yp = CurY+BaseOffs;
-				hl->PtransX = cl.point(zae).x();
-				hl->PtransY = cl.point(zae).y();
-				hl->PRot = rota;
+				QWMatrix savWM = p->worldMatrix();
+				p->setWorldMatrix(trafo);
 				Zli = new ZZ;
 				Zli->Zeich = chx;
 				if (hl->ccolor != "None")
@@ -1722,8 +1847,8 @@ NoRoom: pf2.end();
 				Zli->Farb2 = hl->cstroke;
 				Zli->shade = hl->cshade;
 				Zli->shade2 = hl->cshade2;
-				Zli->xco = hl->xp;
-				Zli->yco = hl->yp;
+				Zli->xco = 0;
+				Zli->yco = BaseOffs;
 				Zli->Sele = hl->cselect;
 				Zli->Siz = chs;
 				Zli->Style = hl->cstyle;
@@ -1734,11 +1859,16 @@ NoRoom: pf2.end();
 				if (!Doc->RePos)
 					DrawZeichenS(p, Zli);
 				delete Zli;
+				p->setWorldMatrix(savWM);
 				p->restore();
 				p->setZoomFactor(sc);
 				MaxChars = a+1;
+				oCurX = CurX;
+				CurX -= dx;
 				CurX += wide+hl->cextra;
+				first = false;
 			}
+		}
 		default:
 			break;
 	}
