@@ -19,15 +19,17 @@ class SxwDialog : public QDialog
 	Q_OBJECT
 
 public:
-	SxwDialog(bool update, bool prefix);
+	SxwDialog(bool update, bool prefix, bool pack);
 	~SxwDialog();
 	bool shouldUpdate();
 	bool usePrefix();
 	bool askAgain();
+	bool packStyles();
 private:
 	QCheckBox* updateCheck;
 	QCheckBox* prefixCheck;
 	QCheckBox* doNotAskCheck;
+	QCheckBox* packCheck;
 	QPushButton* okButton;
 };
 
