@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "cmdtext.h"
 #include "cmdutil.h"
 
@@ -21,6 +29,7 @@ PyObject *scribus_getfontsize(PyObject */*self*/, PyObject* args)
 		for (uint b = 0; b < it->Ptext.count(); b++)
 			if (it->Ptext.at(b)->cselect)
 				return PyFloat_FromDouble(static_cast<double>(it->Ptext.at(b)->csize / 10.0));
+		return NULL;
 	}
 	else
 		return PyFloat_FromDouble(static_cast<long>(it->ISize / 10.0));
@@ -46,6 +55,7 @@ PyObject *scribus_getfont(PyObject */*self*/, PyObject* args)
 		for (uint b = 0; b < it->Ptext.count(); b++)
 			if (it->Ptext.at(b)->cselect)
 				return PyString_FromString(it->Ptext.at(b)->cfont.utf8());
+		return NULL;
 	}
 	else
 		return PyString_FromString(it->IFont.utf8());
@@ -120,7 +130,7 @@ PyObject *scribus_getcolumngap(PyObject */*self*/, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get column gap of non-text frame.","python error"));
 		return NULL;
 	}
-	return PyFloat_FromDouble(static_cast<double>(i->ColGap));
+	return PyFloat_FromDouble(PointToValue(static_cast<double>(i->ColGap)));
 }
 
 PyObject *scribus_getframetext(PyObject */*self*/, PyObject* args)
@@ -307,11 +317,13 @@ PyObject *scribus_inserttext(PyObject */*self*/, PyObject* args)
 	}
 	QString Daten = QString::fromUtf8(Text);
 	PyMem_Free(Text);
-	if ((pos < 0) && (pos > static_cast<int>(it->Ptext.count())))
+	if ((pos < -1) || (pos > static_cast<int>(it->Ptext.count())))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Insert index out of bounds","python error"));
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Insert index out of bounds.","python error"));
 		return NULL;
 	}
+	if (pos == -1)
+		pos = it->Ptext.count();
 	for (uint a = 0; a < Daten.length(); ++a)
 	{
 		struct Pti *hg = new Pti;
@@ -360,7 +372,7 @@ PyObject *scribus_setalign(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (i->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set text alignment on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text alignment on a non-text frame.","python error"));
 		return NULL;
 	}
 	int Apm = Carrier->doc->AppMode;
@@ -385,7 +397,7 @@ PyObject *scribus_setfontsize(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((size > 512) || (size < 1))
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Font size out of bounds - must be 1 <= size <= 512","python error"));
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Font size out of bounds - must be 1 <= size <= 512.","python error"));
 		return NULL;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
@@ -394,7 +406,7 @@ PyObject *scribus_setfontsize(PyObject */*self*/, PyObject* args)
 
 	if (i->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set font size on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set font size on a non-text frame.","python error"));
 		return NULL;
 	}
 	int Apm = Carrier->doc->AppMode;
@@ -422,7 +434,7 @@ PyObject *scribus_setfont(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((i->PType != FRAME_TEXT) && (i->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set font on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set font on a non-text frame.","python error"));
 		return NULL;
 	}
 	if (Carrier->Prefs.AvailFonts.find(QString::fromUtf8(Font)))
@@ -438,7 +450,7 @@ PyObject *scribus_setfont(PyObject */*self*/, PyObject* args)
 	}
 	else
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Font not found","python error"));
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Font not found.","python error"));
 		return NULL;
 	}
 	Py_INCREF(Py_None);
@@ -455,7 +467,7 @@ PyObject *scribus_setlinespace(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (w < 0.1)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Line space out of bounds, must be >= 0.1","python error"));
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Line space out of bounds, must be >= 0.1.","python error"));
 		return NULL;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
@@ -463,7 +475,7 @@ PyObject *scribus_setlinespace(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (i->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't line spacing on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set line spacing on a non-text frame.","python error"));
 		return NULL;
 	}
 	i->LineSp = w;
@@ -481,7 +493,7 @@ PyObject *scribus_setcolumngap(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (w < 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Column gap out of bounds, must be positive","python error"));
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Column gap out of bounds, must be positive.","python error"));
 		return NULL;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
@@ -489,10 +501,10 @@ PyObject *scribus_setcolumngap(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (i->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't column gap on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set column gap on a non-text frame.","python error"));
 		return NULL;
 	}
-	i->ColGap = w;
+	i->ColGap = ValueToPoint(w);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
@@ -507,7 +519,7 @@ PyObject *scribus_setcolumns(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (w < 1)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Column count out of bounds, must be > 1","python error"));
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Column count out of bounds, must be > 1.","python error"));
 		return NULL;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
@@ -515,7 +527,7 @@ PyObject *scribus_setcolumns(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (i->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't number of columns on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set number of columns on a non-text frame.","python error"));
 		return NULL;
 	}
 	i->Cols = w;
@@ -526,26 +538,35 @@ PyObject *scribus_setcolumns(PyObject */*self*/, PyObject* args)
 PyObject *scribus_selecttext(PyObject */*self*/, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
-	int start, ende;
-	if (!PyArg_ParseTuple(args, "ii|es", &start, &ende, "utf-8", &Name))
+	int start, selcount;
+	if (!PyArg_ParseTuple(args, "ii|es", &start, &selcount, "utf-8", &Name))
 		return NULL;
 	if(!checkHaveDocument())
 		return NULL;
 	PageItem *it = GetUniqueItem(QString::fromUtf8(Name));
 	if (it == NULL)
 		return NULL;
-	if ((start < 0) || ((start + ende) > static_cast<int>(it->Ptext.count()-1)))
+	if (selcount == -1)
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Selection index out of bounds","python error"));
+		// user wants to select all after the start point -- CR
+		selcount = it->Ptext.count() - start;
+		if (selcount < 0)
+			// user passed start that's > text in the frame
+			selcount = 0;
+	}
+	// cr 2005-01-18 fixed off-by-one with end bound that made selecting the last char impossible
+	if ((start < 0) || ((start + selcount) > static_cast<int>(it->Ptext.count())))
+	{
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Selection index out of bounds", "python error"));
 		return NULL;
 	}
 	if ((it->PType != FRAME_TEXT) && (it->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't select text in a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot select text in a non-text frame", "python error"));
 		return NULL;
 	}
 	/* FIXME: not sure if we should make this check or not
-	if (start > ende)
+	if (start > selcount)
 	{
 		PyErr_SetString(PyExc_ValueError, QString("Selection start > selection end"));
 		return NULL;
@@ -553,13 +574,13 @@ PyObject *scribus_selecttext(PyObject */*self*/, PyObject* args)
 	*/
 	for (uint a = 0; a < it->Ptext.count(); ++a)
 		it->Ptext.at(a)->cselect = false;
-	if (ende == 0)
+	if (selcount == 0)
 	{
 		it->HasSel = false;
 		Py_INCREF(Py_None);
 		return Py_None;
 	}
-	for (int aa = start; aa < (start + ende); ++aa)
+	for (int aa = start; aa < (start + selcount); ++aa)
 		it->Ptext.at(aa)->cselect = true;
 	it->HasSel = true;
 	Py_INCREF(Py_None);
@@ -578,7 +599,7 @@ PyObject *scribus_deletetext(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((it->PType != FRAME_TEXT) && (it->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't delete text from a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot delete text from a non-text frame.","python error"));
 		return NULL;
 	}
 	if (it->HasSel)
@@ -605,7 +626,7 @@ PyObject *scribus_settextfill(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((it->PType != FRAME_TEXT) && (it->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set text fill on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text fill on a non-text frame.","python error"));
 		return NULL;
 	}
 	else
@@ -639,7 +660,7 @@ PyObject *scribus_settextstroke(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((it->PType != FRAME_TEXT) && (it->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set text stroke on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text stroke on a non-text frame.","python error"));
 		return NULL;
 	}
 	else
@@ -678,7 +699,7 @@ PyObject *scribus_settextshade(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((it->PType != FRAME_TEXT) && (it->PType != FRAME_PATHTEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set text shade on a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set text shade on a non-text frame.","python error"));
 		return NULL;
 	}
 	else
@@ -716,27 +737,27 @@ PyObject *scribus_linktextframes(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if ((fromitem->PType != FRAME_TEXT) || (toitem->PType != FRAME_TEXT))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can only link text frames","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can only link text frames.","python error"));
 		return NULL;
 	}
 	if (toitem->Ptext.count())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Target frame must be empty","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Target frame must be empty.","python error"));
 		return NULL;
 	}
 	if (toitem->NextBox != 0)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Target frame links to another frame","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Target frame links to another frame.","python error"));
 		return NULL;
 	}
 	if (toitem->BackBox != 0)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Target frame is linked to by another frame","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Target frame is linked to by another frame.","python error"));
 		return NULL;
 	}
 	if (toitem == fromitem)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Source and target are the same object","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Source and target are the same object.","python error"));
 		return NULL;
 	}
 	// references to the others boxes
@@ -762,18 +783,18 @@ PyObject *scribus_unlinktextframes(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (item->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't unlink a non-text frame","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot unlink a non-text frame.","python error"));
 		return NULL;
 	}
 	// only linked
 	if (item->BackBox == 0)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Object is not a linked text frame, can't unlink.","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Object is not a linked text frame, cannot unlink.","python error"));
 		return NULL;
 	}
 	if (item->NextBox == 0)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Object the last frame in a series, can't unlink. Unlink the previous frame instead.","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Object the last frame in a series, cannot unlink. Unlink the previous frame instead.","python error"));
 		return NULL;
 	}
 	PageItem* nextbox = item->NextBox;
@@ -814,7 +835,7 @@ PyObject *scribus_tracetext(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if (item->PType != FRAME_TEXT)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't convert a non-text frame to outlines","python error"));
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot convert a non-text frame to outlines.","python error"));
 		return NULL;
 	}
 	Carrier->doc->ActPage = item->OwnPage;
@@ -824,3 +845,56 @@ PyObject *scribus_tracetext(PyObject */*self*/, PyObject* args)
 	Py_INCREF(Py_None);
 	return Py_None;
 }
+
+PyObject *scribus_setpdfbookmark(PyObject */*self*/, PyObject* args)
+{
+	char *name = const_cast<char*>("");
+	bool toggle;
+	if (!PyArg_ParseTuple(args, "b|es", &toggle, "utf-8", &name))
+		return NULL;
+	if (!checkHaveDocument())
+		return NULL;
+	PageItem *i = GetUniqueItem(QString::fromUtf8(name));
+	if (i == NULL)
+		return NULL;
+	if (i->PType != FRAME_TEXT)
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't set bookmark on a non-text frame", "python error"));
+		return NULL;
+	}
+	if (i->isBookmark == toggle)
+	{
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+	if (toggle)
+	{
+		i->isAnnotation = false;
+		Carrier->AddBookMark(i);
+	}
+	else
+		Carrier->DelBookMark(i);
+	i->isBookmark = toggle;
+	Py_INCREF(Py_None);
+	return Py_None;
+}
+
+PyObject *scribus_ispdfbookmark(PyObject */*self*/, PyObject* args)
+{
+	char *name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
+		return NULL;
+	if (!checkHaveDocument())
+		return NULL;
+	PageItem *i = GetUniqueItem(QString::fromUtf8(name));
+	if (i == NULL)
+		return NULL;
+	if (i->PType != FRAME_TEXT)
+	{
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Can't get info from a non-text frame", "python error"));
+		return NULL;
+	}
+	if (i->isBookmark)
+		return PyBool_FromLong(1);
+	return PyBool_FromLong(0);
+}
