@@ -49,6 +49,7 @@ extern void ReOrderText(ScribusDoc *doc, ScribusView *view);
 ScribusView::ScribusView(QWidget *parent, ScribusDoc *doc, preV *prefs)
 		: QScrollView(parent, "s", WRepaintNoErase | WNorthWestGravity)
 {
+	setName("mainView");
 	Ready = false;
 	doZooming = false;
 	Doc = doc;
@@ -468,28 +469,6 @@ void ScribusView::setMenTxt(int Seite)
 	connect(PGS, SIGNAL(GotoPage(int)), this, SLOT(GotoPa(int)));
 }
 
-void ScribusView::setLayMenTxt(int l)
-{
-	QValueList<Layer>::iterator it;
-	QString lName;
-	for (it = Doc->Layers.begin(); it != Doc->Layers.end(); ++it)
-	{
-		if ((*it).LNr == l)
-			break;
-	}
-	lName=(*it).Name;
-	int len = lName.length();
-	while (LY->fontMetrics().width(lName) > LY->width()-25)
-	{
-		len--;
-		if (len == 0)
-			break;
-		lName.truncate(len);
-		lName += ".";
-	}
-	LY->setText(lName);
-}
-
 /** Fuehrt die Vergroesserung/Verkleinerung aus */
 void ScribusView::slotDoZoom()
 {
@@ -582,6 +561,7 @@ void ScribusView::LaMenu()
 {
 	uint a;
 	QValueList<Layer>::iterator it;
+	disconnect(Laymen, SIGNAL(activated(int)), this, SLOT(GotoLa(int)));
  	Laymen->clear();
  	if (Doc->Layers.count() != 0)
  	{
@@ -600,23 +580,50 @@ void ScribusView::LaMenu()
 			Laymen->setItemChecked(Laymen->idAt(curr), true);
  		}
  	}
+	connect(Laymen, SIGNAL(activated(int)), this, SLOT(GotoLa(int)));
+}
+
+void ScribusView::setLayMenTxt(int l)
+{
+	QValueList<Layer>::iterator it;
+	QString lName;
+	for (it = Doc->Layers.begin(); it != Doc->Layers.end(); ++it)
+	{
+		if ((*it).LNr == l)
+			break;
+	}
+	lName=(*it).Name;
+	int len = lName.length();
+	while (LY->fontMetrics().width(lName) > LY->width()-25)
+	{
+		len--;
+		if (len == 0)
+			break;
+		lName.truncate(len);
+		lName += ".";
+	}
+	LY->setText(lName);
 }
 
 void ScribusView::GotoLa(int l)
 {
-	int a=0;
 	int d = Doc->Layers.count()-Laymen->indexOf(l)-1;
 	QValueList<Layer>::iterator it;
-	for (it = Doc->Layers.begin(); it != Doc->Layers.end(); ++it,a++)
+	for (it = Doc->Layers.begin(); it != Doc->Layers.end(); ++it)
 	{
 		if ( d == (*it).Level )
 		{
-			Doc->ActiveLayer = a;
-			LY->setText(Doc->Layers[a].Name);
-			emit changeLA(a);
+			Doc->ActiveLayer = (*it).LNr;
+			setLayMenTxt((*it).LNr);
+			emit changeLA((*it).LNr);
 			break;
 		}
 	}
+	for (uint al = 0; al < Laymen->count(); ++al)
+	{
+		Laymen->setItemChecked(Laymen->idAt(al), false);
+	}
+	Laymen->setItemChecked(l, true);
 }
 
 void ScribusView::GotoPa(int Seite)
@@ -747,6 +754,7 @@ void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 		counter = 0;
 	if (Pages.count() != 0)
 	{
+		int fho, fvo;
 		for (a=0; a < Pages.count(); a++)
 		{
 			Doc->ActPage = Pages.at(a);
@@ -755,6 +763,8 @@ void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 				it = Pages.at(a)->Items.at(i);
 				if ((it->PType == 2) && (it->PicAvail))
 				{
+					fho = it->flippedH;
+					fvo = it->flippedV;
 					if (Pr->contains(it->IProfile))
 						Pages.at(a)->LoadPict(it->Pfile, i);
 					else
@@ -762,6 +772,8 @@ void ScribusView::RecalcPictures(ProfilesL *Pr, QProgressBar *dia)
 						it->IProfile = Doc->CMSSettings.DefaultInputProfile;
 						Pages.at(a)->LoadPict(it->Pfile, i);
 					}
+					it->flippedH = fho;
+					it->flippedV = fvo;
 					it->Sizing = true;
 					Pages.at(a)->AdjustPreview(it);
 					it->Sizing = false;
@@ -977,7 +989,7 @@ QPixmap ScribusView::PageToPixmap(int Nr, int maxGr)
 	return pm;
 }
 
-void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString SepNam, bool farb, bool Hm, bool Vm, bool Ic, bool gcr)
+void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString SepNam, bool farb, bool Hm, bool Vm, bool Ic, bool gcr, bool doDev)
 {
 	uint a;
 	int sepac;
@@ -994,10 +1006,10 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 	{
 		Doc->ActPage->setGroupRect();
 		Doc->ActPage->getGroupRect(&gx, &gy, &gw, &gh);
-		p->PS_begin_doc(Doc->PageOri, gx, Doc->PageH - (gy+gh), gx + gw, Doc->PageH - gy, pageNs.size());
+		p->PS_begin_doc(Doc->PageOri, gx, Doc->PageH - (gy+gh), gx + gw, Doc->PageH - gy, pageNs.size(), false);
 	}
 	else
-		p->PS_begin_doc(Doc->PageOri, 0.0, 0.0, Doc->PageB, Doc->PageH, pageNs.size());
+		p->PS_begin_doc(Doc->PageOri, 0.0, 0.0, Doc->PageB, Doc->PageH, pageNs.size(), doDev);
 	for (uint ap = 0; ap < MasterPages.count(); ++ap)
 	{
 		int Lnr = 0;
@@ -1014,11 +1026,10 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 					for (uint api = 0; api < MasterPages.at(ap)->Items.count(); ++api)
 					{
 						int h, s, v, k, tsz;
-						double wideR;
 						struct Pti *hl;
 						QString tmps, chx;
 						PageItem *c = MasterPages.at(ap)->Items.at(api);
-						if (c->LayerNr != ll.LNr)
+						if ((c->LayerNr != ll.LNr) || (!c->isPrintable))
 							continue;
 						if ((c->PType == 2) && (c->PicAvail) && (c->Pfile != "") && (c->isPrintable) && (!sep) && (farb))
 							p->PS_ImageData(c->InvPict, c->Pfile, c->AnName, c->IProfile, c->UseEmbedded, Ic);
@@ -1204,33 +1215,18 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 										if (((*Doc->AllFonts)[hl->cfont]->CharWidth.contains(chr)) && (chr != 32))
 										{
 											p->PS_save();
-											p->PS_translate(hl->PtransX, -hl->PtransY);
-											p->PS_rotate(-hl->PRot);
-											if (c->Reverse)
-											{
-												p->PS_translate(hl->xp, (hl->yp - (tsz / 10.0)) * -1);
-												p->PS_scale(-1, 1);
-												if (d < c->MaxChars-1)
-												{
-													QString ctx = c->Ptext.at(d+1)->ch;
-													if (ctx == QChar(29))
-														ctx = " ";
-													if (ctx == QChar(0xA0))
-														ctx = " ";
-													wideR = -Cwidth(Doc, hl->cfont, chx, tsz, ctx) * (hl->cscale / 100.0);
-												}
-												else
-													wideR = -Cwidth(Doc, hl->cfont, chx, tsz) * (hl->cscale / 100.0);
-												p->PS_translate(wideR, 0);
-											}
-											else
-												p->PS_translate(hl->xp, (hl->yp - (tsz / 10.0)) * -1);
 											if (hl->cscale != 100)
 												p->PS_scale(hl->cscale / 100.0, 1);
 											if (hl->ccolor != "None")
 											{
 												SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 												p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+												p->PutSeite("[ 1 0 0 -1 " + p->ToStr(-hl->PRot) + " 0 ]\n");
+												p->PutSeite("["+p->ToStr(hl->PtransX) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransX) + " " + p->ToStr(hl->xp) + " " + p->ToStr(-hl->yp) + "]\n");
+												p->PutSeite("[ 0 0 0 0 0 0 ] concatmatrix\nconcat\n");
+												p->PS_translate(0, (tsz / 10.0));
+												if (c->BaseOffs != 0)
+													p->PS_translate(0, -c->BaseOffs);
 												p->PS_showSub(chr, (*Doc->AllFonts)[hl->cfont]->RealName().simplifyWhiteSpace().replace( QRegExp("\\s"), "" ), tsz / 10.0, false);
 											}
 											p->PS_restore();
@@ -1240,9 +1236,12 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 									{
 										p->PS_selectfont(hl->cfont, tsz / 10.0);
 										p->PS_save();
-										p->PS_translate(hl->PtransX, -hl->PtransY);
-										p->PS_rotate(-hl->PRot);
-										p->PS_show_xyG(hl->cfont, chx, hl->xp, -hl->yp);
+										p->PutSeite("[ 1 0 0 -1 " + p->ToStr(-hl->PRot) + " 0 ]\n");
+										p->PutSeite("["+p->ToStr(hl->PtransX) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransX) + " " + p->ToStr(hl->xp) + " " + p->ToStr(-hl->yp) + "]\n");
+										p->PutSeite("[ 0 0 0 0 0 0 ] concatmatrix\nconcat\n");
+										if (c->BaseOffs != 0)
+											p->PS_translate(0, -c->BaseOffs);
+										p->PS_show_xyG(hl->cfont, chx, 0, 0);
 										p->PS_restore();
 									}
 								}
@@ -1253,6 +1252,7 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 						p->PS_TemplateEnd();
 					}
 				}
+				Lnr++;
 			}
 		}
 	}
@@ -1599,7 +1599,7 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 												p->PS_setlinewidth(QMAX((*Doc->AllFonts)[hl->cfont]->strokeWidth / 2 * (tsz / 10.0), 1));
 												p->PS_setcapjoin(FlatCap, MiterJoin);
 												p->PS_setdash(SolidLine, 0, dum);
-												p->PS_translate(hl->xp, (hl->yp - tsz) * -1);
+												p->PS_translate(hl->xp, (hl->yp - (tsz / 10.0)) * -1);
 												SetFarbe(hl->cstroke, hl->cshade2, &h, &s, &v, &k, gcr);
 												p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
 												SetClipPath(p, &gly);
@@ -1613,6 +1613,11 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 									{
 										double Ulen = Cwidth(Doc, hl->cfont, chx, hl->csize) * (hl->cscale / 100.0);
 										double Upos = (*Doc->AllFonts)[hl->cfont]->strikeout_pos * (tsz / 10.0);
+										double kern;
+										if (hl->cstyle & 1024)
+											kern = 0;
+										else
+											kern = hl->cextra;
 										if (hl->ccolor != "None")
 										{
 											p->PS_setcapjoin(FlatCap, MiterJoin);
@@ -1620,8 +1625,8 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 											SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 											p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
 										}
-										p->PS_setlinewidth((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0));
-										p->PS_moveto(hl->xp, -hl->yp+Upos);
+										p->PS_setlinewidth(QMAX((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0), 1));
+										p->PS_moveto(hl->xp-kern, -hl->yp+Upos);
 										p->PS_lineto(hl->xp+Ulen, -hl->yp+Upos);
 										p->PS_stroke();
 									}
@@ -1629,6 +1634,11 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 									{
 										double Ulen = Cwidth(Doc, hl->cfont, chx, hl->csize) * (hl->cscale / 100.0);
 										double Upos = (*Doc->AllFonts)[hl->cfont]->underline_pos * (tsz / 10.0);
+										double kern;
+										if (hl->cstyle & 1024)
+											kern = 0;
+										else
+											kern = hl->cextra;
 										if (hl->ccolor != "None")
 										{
 											p->PS_setcapjoin(FlatCap, MiterJoin);
@@ -1636,8 +1646,8 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 											SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 											p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
 										}
-										p->PS_setlinewidth((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0));
-										p->PS_moveto(hl->xp, -hl->yp+Upos);
+										p->PS_setlinewidth(QMAX((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0), 1));
+										p->PS_moveto(hl->xp-kern, -hl->yp+Upos);
 										p->PS_lineto(hl->xp+Ulen, -hl->yp+Upos);
 										p->PS_stroke();
 									}
@@ -1645,7 +1655,7 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 									{
 										int chs = hl->csize;
 										ite->SetZeichAttr(hl, &chs, &chx);
-										double wide = Cwidth(Doc, hl->cfont, chx, chs);
+										double wide = Cwidth(Doc, hl->cfont, chx, chs) * (hl->cscale / 100.0);
 										chx = "-";
 										uint chr = chx[0].unicode();
 										if ((*Doc->AllFonts)[hl->cfont]->CharWidth.contains(chr))
@@ -2117,6 +2127,11 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 							{
 								double Ulen = Cwidth(Doc, hl->cfont, chx, hl->csize) * (hl->cscale / 100.0);
 								double Upos = (*Doc->AllFonts)[hl->cfont]->strikeout_pos * (tsz / 10.0);
+								double kern;
+								if (hl->cstyle & 1024)
+									kern = 0;
+								else
+									kern = hl->cextra;
 								if (hl->ccolor != "None")
 								{
 									p->PS_setcapjoin(FlatCap, MiterJoin);
@@ -2124,8 +2139,8 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 									SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 									p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
 								}
-								p->PS_setlinewidth((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0));
-								p->PS_moveto(hl->xp, -hl->yp+Upos);
+								p->PS_setlinewidth(QMAX((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0), 1));
+								p->PS_moveto(hl->xp-kern, -hl->yp+Upos);
 								p->PS_lineto(hl->xp+Ulen, -hl->yp+Upos);
 								p->PS_stroke();
 							}
@@ -2133,6 +2148,11 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 							{
 								double Ulen = Cwidth(Doc, hl->cfont, chx, hl->csize) * (hl->cscale / 100.0);
 								double Upos = (*Doc->AllFonts)[hl->cfont]->underline_pos * (tsz / 10.0);
+								double kern;
+								if (hl->cstyle & 1024)
+									kern = 0;
+								else
+									kern = hl->cextra;
 								if (hl->ccolor != "None")
 								{
 									p->PS_setcapjoin(FlatCap, MiterJoin);
@@ -2140,8 +2160,8 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 									SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 									p->PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
 								}
-								p->PS_setlinewidth((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0));
-								p->PS_moveto(hl->xp, -hl->yp+Upos);
+								p->PS_setlinewidth(QMAX((*Doc->AllFonts)[hl->cfont]->strokeWidth * (tsz / 10.0), 1));
+								p->PS_moveto(hl->xp-kern, -hl->yp+Upos);
 								p->PS_lineto(hl->xp+Ulen, -hl->yp+Upos);
 								p->PS_stroke();
 							}
@@ -2149,7 +2169,7 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 							{
 								int chs = hl->csize;
 								c->SetZeichAttr(hl, &chs, &chx);
-								double wide = Cwidth(Doc, hl->cfont, chx, chs);
+								double wide = Cwidth(Doc, hl->cfont, chx, chs) * (hl->cscale / 100.0);
 								chx = "-";
 								uint chr = chx[0].unicode();
 								if ((*Doc->AllFonts)[hl->cfont]->CharWidth.contains(chr))
@@ -2362,33 +2382,18 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 								if (((*Doc->AllFonts)[hl->cfont]->CharWidth.contains(chr)) && (chr != 32))
 								{
 									p->PS_save();
-									p->PS_translate(hl->PtransX, -hl->PtransY);
-									p->PS_rotate(-hl->PRot);
-									if (c->Reverse)
-									{
-										p->PS_translate(hl->xp, (hl->yp - (tsz / 10.0)) * -1);
-										p->PS_scale(-1, 1);
-										if (d < c->MaxChars-1)
-										{
-											QString ctx = c->Ptext.at(d+1)->ch;
-											if (ctx == QChar(29))
-												ctx = " ";
-											if (ctx == QChar(0xA0))
-												ctx = " ";
-											wideR = -Cwidth(Doc, hl->cfont, chx, tsz, ctx) * (hl->cscale / 100.0);
-										}
-										else
-											wideR = -Cwidth(Doc, hl->cfont, chx, tsz) * (hl->cscale / 100.0);
-										p->PS_translate(wideR, 0);
-									}
-									else
-										p->PS_translate(hl->xp, (hl->yp - (tsz / 10.0)) * -1);
 									if (hl->cscale != 100)
 										p->PS_scale(hl->cscale / 100.0, 1);
 									if (hl->ccolor != "None")
 									{
 										SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
 										p->PS_setcmykcolor_fill(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+										p->PutSeite("[ 1 0 0 -1 " + p->ToStr(-hl->PRot) + " 0 ]\n");
+										p->PutSeite("["+p->ToStr(hl->PtransX) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransX) + " " + p->ToStr(hl->xp) + " " + p->ToStr(-hl->yp) + "]\n");
+										p->PutSeite("[ 0 0 0 0 0 0 ] concatmatrix\nconcat\n");
+										p->PS_translate(0, (tsz / 10.0));
+										if (c->BaseOffs != 0)
+											p->PS_translate(0, -c->BaseOffs);
 										p->PS_showSub(chr, (*Doc->AllFonts)[hl->cfont]->RealName().simplifyWhiteSpace().replace( QRegExp("\\s"), "" ), tsz / 10.0, false);
 									}
 									p->PS_restore();
@@ -2398,9 +2403,12 @@ void ScribusView::ProcessPage(PSLib *p, Page* a, uint PNr, bool sep, bool farb,
 							{
 								p->PS_selectfont(hl->cfont, tsz / 10.0);
 								p->PS_save();
-								p->PS_translate(hl->PtransX, -hl->PtransY);
-								p->PS_rotate(-hl->PRot);
-								p->PS_show_xyG(hl->cfont, chx, hl->xp, -hl->yp);
+								p->PutSeite("[ 1 0 0 -1 " + p->ToStr(-hl->PRot) + " 0 ]\n");
+								p->PutSeite("["+p->ToStr(hl->PtransX) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransY) + " " + p->ToStr(-hl->PtransX) + " " + p->ToStr(hl->xp) + " " + p->ToStr(-hl->yp) + "]\n");
+								p->PutSeite("[ 0 0 0 0 0 0 ] concatmatrix\nconcat\n");
+								if (c->BaseOffs != 0)
+									p->PS_translate(0, -c->BaseOffs);
+								p->PS_show_xyG(hl->cfont, chx, 0, 0);
 								p->PS_restore();
 							}
 						}
@@ -2514,10 +2522,10 @@ void ScribusView::HandleGradient(PSLib *p, PageItem *c, double w, double h, bool
 			break;
 		case 6:
 		case 7:
-			StartX = c->GrStartX;
-			StartY = c->GrStartY;
-			EndX = c->GrEndX;
-			EndY = c->GrEndY;
+			StartX = QMIN(QMAX(c->GrStartX, 0), c->Width);
+			StartY = QMIN(QMAX(c->GrStartY, 0), c->Height);
+			EndX = QMIN(QMAX(c->GrEndX, 0), c->Width);
+			EndY = QMIN(QMAX(c->GrEndY, 0), c->Height);
 			break;
 	}
 	QValueList<double> StopVec;
@@ -2627,3 +2635,66 @@ void ScribusView::contentsWheelEvent(QWheelEvent *w)
 	}
 	w->accept();
 }
+
+bool ScribusView::nameExists(const QString itemName)
+{
+	bool found = false;
+	for (uint a = 0; a < Pages.count(); ++a)
+	{
+		for (uint c = 0; c < Pages.at(a)->Items.count(); ++c)
+		{
+			if (itemName == Pages.at(a)->Items.at(c)->AnName)
+			{
+				found = true;
+				break;
+			}
+		}
+		if (found)
+			break;
+	}
+	return found;
+}
+
+QString ScribusView::generateUniqueCopyName(const QString originalName)
+{
+	if (!nameExists(originalName))
+		return originalName;
+
+	// Start embellishing the name until we get an acceptable unique name
+	// first we prefix `Copy of' if it's not already there
+	QString newname(originalName);
+	if (!originalName.startsWith(tr("Copy of")))
+		newname.prepend(tr("Copy of")+" ");
+
+	// See if the name prefixed by "Copy of " is free
+	if (nameExists(newname))
+	{
+		// Search the string for (number) at the end and capture
+		// both the number and the text leading up to it sans brackets.
+		//     Copy of fred (5)
+		//     ^^^^^^^^^^^^  ^   (where ^ means captured)
+		QRegExp rx("^(.*)\\s+\\((\\d+)\\)$");
+		int numMatches = rx.searchRev(newname);
+		// Add a (number) suffix to the end of the name. We start at the
+		// old suffix's value if there was one, or at 2 if there was not.
+		int suffixnum = 2;
+		QString prefix(newname);
+		if (numMatches != -1)
+		{
+			// Already had a suffix; use the name w/o suffix for prefix and
+			// grab the old suffix value as a starting point.
+			QStringList matches = rx.capturedTexts();
+			prefix = matches[1];
+			suffixnum = matches[2].toInt();
+		}
+		// Keep on incrementing the suffix 'till we find a free name
+		do
+		{
+			newname = prefix + " (" + QString::number(suffixnum) + ")";
+			suffixnum ++;
+		}
+		while (nameExists(newname));
+	}
+	assert(!nameExists(newname));
+	return newname;
+}
